RuleEffect

Enum RuleEffect 

pub enum RuleEffect {
    Permit,
    Deny,
}
NACM Rule effect (permit or deny)

This enum represents the final decision for an access request. In NACM, every rule must have an action that either permits or denies access.

Examples

use nacm_validator::RuleEffect;
 
let permit = RuleEffect::Permit;
let deny = RuleEffect::Deny;
 
// Rules with permit effects allow access
assert_eq!(permit == RuleEffect::Permit, true);

Variants



Permit

Allow the requested access



Deny

Deny the requested access